==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ImageContentPolicySpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageContentPolicySpecFluentImpl<A extends ImageContentPolicySpecFluent<A>> extends BaseFluent<A> implements ImageContentPolicySpecFluent<A>{
  public ImageContentPolicySpecFluentImpl() {
  }
  public ImageContentPolicySpecFluentImpl(ImageContentPolicySpec instance) {
    this.withRepositoryDigestMirrors(instance.getRepositoryDigestMirrors()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<RepositoryDigestMirrorsBuilder> repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToRepositoryDigestMirrors(Integer index,RepositoryDigestMirrors item) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").add(index >= 0 ? index : _visitables.get("repositoryDigestMirrors").size(), builder);this.repositoryDigestMirrors.add(index >= 0 ? index : repositoryDigestMirrors.size(), builder); return (A)this;
  }
  public A setToRepositoryDigestMirrors(Integer index,RepositoryDigestMirrors item) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);
    if (index < 0 || index >= _visitables.get("repositoryDigestMirrors").size()) { _visitables.get("repositoryDigestMirrors").add(builder); } else { _visitables.get("repositoryDigestMirrors").set(index, builder);}
    if (index < 0 || index >= repositoryDigestMirrors.size()) { repositoryDigestMirrors.add(builder); } else { repositoryDigestMirrors.set(index, builder);}
     return (A)this;
  }
  public A addToRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... items) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").add(builder);this.repositoryDigestMirrors.add(builder);} return (A)this;
  }
  public A addAllToRepositoryDigestMirrors(Collection<RepositoryDigestMirrors> items) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").add(builder);this.repositoryDigestMirrors.add(builder);} return (A)this;
  }
  public A removeFromRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... items) {
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").remove(builder);if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.remove(builder);}} return (A)this;
  }
  public A removeAllFromRepositoryDigestMirrors(Collection<RepositoryDigestMirrors> items) {
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").remove(builder);if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRepositoryDigestMirrors(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    if (repositoryDigestMirrors == null) return (A) this;
    final Iterator<RepositoryDigestMirrorsBuilder> each = repositoryDigestMirrors.iterator();
    final List visitables = _visitables.get("repositoryDigestMirrors");
    while (each.hasNext()) {
      RepositoryDigestMirrorsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRepositoryDigestMirrors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RepositoryDigestMirrors> getRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null ? build(repositoryDigestMirrors) : null;
  }
  public List<RepositoryDigestMirrors> buildRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null ? build(repositoryDigestMirrors) : null;
  }
  public RepositoryDigestMirrors buildRepositoryDigestMirror(Integer index) {
    return this.repositoryDigestMirrors.get(index).build();
  }
  public RepositoryDigestMirrors buildFirstRepositoryDigestMirror() {
    return this.repositoryDigestMirrors.get(0).build();
  }
  public RepositoryDigestMirrors buildLastRepositoryDigestMirror() {
    return this.repositoryDigestMirrors.get(repositoryDigestMirrors.size() - 1).build();
  }
  public RepositoryDigestMirrors buildMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    for (RepositoryDigestMirrorsBuilder item: repositoryDigestMirrors) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    for (RepositoryDigestMirrorsBuilder item: repositoryDigestMirrors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRepositoryDigestMirrors(List<RepositoryDigestMirrors> repositoryDigestMirrors) {
    if (this.repositoryDigestMirrors != null) { _visitables.get("repositoryDigestMirrors").removeAll(this.repositoryDigestMirrors);}
    if (repositoryDigestMirrors != null) {this.repositoryDigestMirrors = new ArrayList(); for (RepositoryDigestMirrors item : repositoryDigestMirrors){this.addToRepositoryDigestMirrors(item);}} else { this.repositoryDigestMirrors = null;} return (A) this;
  }
  public A withRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... repositoryDigestMirrors) {
    if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.clear();}
    if (repositoryDigestMirrors != null) {for (RepositoryDigestMirrors item :repositoryDigestMirrors){ this.addToRepositoryDigestMirrors(item);}} return (A) this;
  }
  public Boolean hasRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null && !repositoryDigestMirrors.isEmpty();
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> addNewRepositoryDigestMirror() {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl();
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> addNewRepositoryDigestMirrorLike(RepositoryDigestMirrors item) {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl(-1, item);
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> setNewRepositoryDigestMirrorLike(Integer index,RepositoryDigestMirrors item) {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl(index, item);
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> editRepositoryDigestMirror(Integer index) {
    if (repositoryDigestMirrors.size() <= index) throw new RuntimeException("Can't edit repositoryDigestMirrors. Index exceeds size.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> editFirstRepositoryDigestMirror() {
    if (repositoryDigestMirrors.size() == 0) throw new RuntimeException("Can't edit first repositoryDigestMirrors. The list is empty.");
    return setNewRepositoryDigestMirrorLike(0, buildRepositoryDigestMirror(0));
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> editLastRepositoryDigestMirror() {
    int index = repositoryDigestMirrors.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last repositoryDigestMirrors. The list is empty.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<A> editMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<repositoryDigestMirrors.size();i++) { 
    if (predicate.test(repositoryDigestMirrors.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching repositoryDigestMirrors. No match found.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageContentPolicySpecFluentImpl that = (ImageContentPolicySpecFluentImpl) o;
    if (repositoryDigestMirrors != null ? !repositoryDigestMirrors.equals(that.repositoryDigestMirrors) :that.repositoryDigestMirrors != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(repositoryDigestMirrors,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (repositoryDigestMirrors != null && !repositoryDigestMirrors.isEmpty()) { sb.append("repositoryDigestMirrors:"); sb.append(repositoryDigestMirrors + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RepositoryDigestMirrorsNestedImpl<N> extends RepositoryDigestMirrorsFluentImpl<ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<N>> implements ImageContentPolicySpecFluent.RepositoryDigestMirrorsNested<N>,Nested<N>{
    RepositoryDigestMirrorsNestedImpl(Integer index,RepositoryDigestMirrors item) {
      this.index = index;
      this.builder = new RepositoryDigestMirrorsBuilder(this, item);
    }
    RepositoryDigestMirrorsNestedImpl() {
      this.index = -1;
      this.builder = new RepositoryDigestMirrorsBuilder(this);
    }
    RepositoryDigestMirrorsBuilder builder;
    Integer index;
    public N and() {
      return (N) ImageContentPolicySpecFluentImpl.this.setToRepositoryDigestMirrors(index,builder.build());
    }
    public N endRepositoryDigestMirror() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ImageContentPolicySpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageContentPolicySpecFluentImpl<A extends ImageContentPolicySpecFluent<A>> extends BaseFluent<A> implements ImageContentPolicySpecFluent<A>{
  public ImageContentPolicySpecFluentImpl() {
  }
  public ImageContentPolicySpecFluentImpl(ImageContentPolicySpec instance) {
    if (instance != null) {
      this.withRepositoryDigestMirrors(instance.getRepositoryDigestMirrors());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<RepositoryDigestMirrorsBuilder> repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToRepositoryDigestMirrors(int index,RepositoryDigestMirrors item) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);
    if (index < 0 || index >= repositoryDigestMirrors.size()) { _visitables.get("repositoryDigestMirrors").add(builder); repositoryDigestMirrors.add(builder); } else { _visitables.get("repositoryDigestMirrors").add(index, builder); repositoryDigestMirrors.add(index, builder);}
    return (A)this;
  }
  public A setToRepositoryDigestMirrors(int index,RepositoryDigestMirrors item) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);
    if (index < 0 || index >= repositoryDigestMirrors.size()) { _visitables.get("repositoryDigestMirrors").add(builder); repositoryDigestMirrors.add(builder); } else { _visitables.get("repositoryDigestMirrors").set(index, builder); repositoryDigestMirrors.set(index, builder);}
    return (A)this;
  }
  public A addToRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... items) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").add(builder);this.repositoryDigestMirrors.add(builder);} return (A)this;
  }
  public A addAllToRepositoryDigestMirrors(Collection<RepositoryDigestMirrors> items) {
    if (this.repositoryDigestMirrors == null) {this.repositoryDigestMirrors = new ArrayList<RepositoryDigestMirrorsBuilder>();}
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").add(builder);this.repositoryDigestMirrors.add(builder);} return (A)this;
  }
  public A removeFromRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... items) {
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").remove(builder);if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.remove(builder);}} return (A)this;
  }
  public A removeAllFromRepositoryDigestMirrors(Collection<RepositoryDigestMirrors> items) {
    for (RepositoryDigestMirrors item : items) {RepositoryDigestMirrorsBuilder builder = new RepositoryDigestMirrorsBuilder(item);_visitables.get("repositoryDigestMirrors").remove(builder);if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRepositoryDigestMirrors(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    if (repositoryDigestMirrors == null) return (A) this;
    final Iterator<RepositoryDigestMirrorsBuilder> each = repositoryDigestMirrors.iterator();
    final List visitables = _visitables.get("repositoryDigestMirrors");
    while (each.hasNext()) {
      RepositoryDigestMirrorsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRepositoryDigestMirrors instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RepositoryDigestMirrors> getRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null ? build(repositoryDigestMirrors) : null;
  }
  public List<RepositoryDigestMirrors> buildRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null ? build(repositoryDigestMirrors) : null;
  }
  public RepositoryDigestMirrors buildRepositoryDigestMirror(int index) {
    return this.repositoryDigestMirrors.get(index).build();
  }
  public RepositoryDigestMirrors buildFirstRepositoryDigestMirror() {
    return this.repositoryDigestMirrors.get(0).build();
  }
  public RepositoryDigestMirrors buildLastRepositoryDigestMirror() {
    return this.repositoryDigestMirrors.get(repositoryDigestMirrors.size() - 1).build();
  }
  public RepositoryDigestMirrors buildMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    for (RepositoryDigestMirrorsBuilder item: repositoryDigestMirrors) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    for (RepositoryDigestMirrorsBuilder item: repositoryDigestMirrors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRepositoryDigestMirrors(List<RepositoryDigestMirrors> repositoryDigestMirrors) {
    if (this.repositoryDigestMirrors != null) { _visitables.get("repositoryDigestMirrors").clear();}
    if (repositoryDigestMirrors != null) {this.repositoryDigestMirrors = new ArrayList(); for (RepositoryDigestMirrors item : repositoryDigestMirrors){this.addToRepositoryDigestMirrors(item);}} else { this.repositoryDigestMirrors = null;} return (A) this;
  }
  public A withRepositoryDigestMirrors(io.fabric8.openshift.api.model.config.v1.RepositoryDigestMirrors... repositoryDigestMirrors) {
    if (this.repositoryDigestMirrors != null) {this.repositoryDigestMirrors.clear(); _visitables.remove("repositoryDigestMirrors"); }
    if (repositoryDigestMirrors != null) {for (RepositoryDigestMirrors item :repositoryDigestMirrors){ this.addToRepositoryDigestMirrors(item);}} return (A) this;
  }
  public Boolean hasRepositoryDigestMirrors() {
    return repositoryDigestMirrors != null && !repositoryDigestMirrors.isEmpty();
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> addNewRepositoryDigestMirror() {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl();
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> addNewRepositoryDigestMirrorLike(RepositoryDigestMirrors item) {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl(-1, item);
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> setNewRepositoryDigestMirrorLike(int index,RepositoryDigestMirrors item) {
    return new ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNestedImpl(index, item);
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> editRepositoryDigestMirror(int index) {
    if (repositoryDigestMirrors.size() <= index) throw new RuntimeException("Can't edit repositoryDigestMirrors. Index exceeds size.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> editFirstRepositoryDigestMirror() {
    if (repositoryDigestMirrors.size() == 0) throw new RuntimeException("Can't edit first repositoryDigestMirrors. The list is empty.");
    return setNewRepositoryDigestMirrorLike(0, buildRepositoryDigestMirror(0));
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> editLastRepositoryDigestMirror() {
    int index = repositoryDigestMirrors.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last repositoryDigestMirrors. The list is empty.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<A> editMatchingRepositoryDigestMirror(Predicate<RepositoryDigestMirrorsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<repositoryDigestMirrors.size();i++) { 
    if (predicate.test(repositoryDigestMirrors.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching repositoryDigestMirrors. No match found.");
    return setNewRepositoryDigestMirrorLike(index, buildRepositoryDigestMirror(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageContentPolicySpecFluentImpl that = (ImageContentPolicySpecFluentImpl) o;
    if (!java.util.Objects.equals(repositoryDigestMirrors, that.repositoryDigestMirrors)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(repositoryDigestMirrors,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (repositoryDigestMirrors != null) { sb.append("repositoryDigestMirrors:"); sb.append(repositoryDigestMirrors + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class RepositoryDigestMirrorsNestedImpl<N> extends RepositoryDigestMirrorsFluentImpl<ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<N>> implements ImageContentPolicySpecFluentImpl.RepositoryDigestMirrorsNested<N>,Nested<N>{
    RepositoryDigestMirrorsNestedImpl(int index,RepositoryDigestMirrors item) {
      this.index = index;
      this.builder = new RepositoryDigestMirrorsBuilder(this, item);
    }
    RepositoryDigestMirrorsNestedImpl() {
      this.index = -1;
      this.builder = new RepositoryDigestMirrorsBuilder(this);
    }
    RepositoryDigestMirrorsBuilder builder;
    int index;
    public N and() {
      return (N) ImageContentPolicySpecFluentImpl.this.setToRepositoryDigestMirrors(index,builder.build());
    }
    public N endRepositoryDigestMirror() {
      return and();
    }
    
  }
  
}
